inet.data.format.flat

Functions to load inet.data entities from flat, line-oriented files.

Functions to load inet.data entities from flat, line-oriented files.
raw docstring

inet.data.format.psl

Functions to use Mozilla Public Suffix List format files.

The supported format extends the PSL format. It has these differences:

  • Lines that begin with # are comments. Lines that begin with // are also comments.

  • A + before a domain indicates a "dynamic" rule. Dynamic rules act as normal rules unless the lookup domain is identical to the suffix domain. In this case, the lookup continues with the next matching rule.

See the tests for examples.

Functions to use Mozilla Public Suffix List format files.

The supported format extends the PSL format. It has these differences:

- Lines that begin with `#` are comments. Lines that begin with `//` are also
  comments.

- A `+` before a domain indicates a "dynamic" rule. Dynamic rules act as
  normal rules unless the lookup domain is identical to the suffix domain. In
  this case, the lookup continues with the next matching rule.

See the tests for examples.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries