Conversion between IP addresses or networks and reverse-DNS domains.
This namespace connects inet.data.ip and inet.data.dns. Neither namespace
depends on the other.
Conversion between IP addresses or networks and reverse-DNS domains. This namespace connects `inet.data.ip` and `inet.data.dns`. Neither namespace depends on the other.
Functions for interacting with DNS domain names.
This namespace represents domain names internally in a normalized byte-oriented form. The normalized form has these properties:
This form has these benefits:
The main disadvantage is that this form makes it more difficult to find the immediate parent of a given domain.
Functions for interacting with DNS domain names. This namespace represents domain names internally in a normalized byte-oriented form. The normalized form has these properties: - IDN labels use IDNA encoding. - Domain labels go from top-level to bottom-level. This is the reverse of the usual order. - A byte comes before each label. The byte gives the count of bytes in the label. This form has these benefits: - It can represent any binary data accurately, the same as the DNS wire form. - Lexicographic byte order is also hierarchical order. - For a given child domain and ancestor domain, you can find the next longer child of the ancestor. The main disadvantage is that this form makes it more difficult to find the immediate parent of a given domain.
Functions to load inet.data entities from flat, line-oriented files.
Functions to load inet.data entities from flat, line-oriented files.
Functions to use Mozilla Public Suffix List format files.
The supported format extends the PSL format. It has these differences:
Lines that begin with # are comments. Lines that begin with // are also
comments.
A + before a domain indicates a "dynamic" rule. Dynamic rules act as
normal rules unless the lookup domain is identical to the suffix domain. In
this case, the lookup continues with the next matching rule.
See the tests for examples.
Functions to use Mozilla Public Suffix List format files. The supported format extends the PSL format. It has these differences: - Lines that begin with `#` are comments. Lines that begin with `//` are also comments. - A `+` before a domain indicates a "dynamic" rule. Dynamic rules act as normal rules unless the lookup domain is identical to the suffix domain. In this case, the lookup continues with the next matching rule. See the tests for examples.
Functions for interacting with IP addresses and networks.
Functions for interacting with IP addresses and networks.
Avro serialization implementations for inet.data types.
Avro serialization implementations for inet.data types.
Byteable serialization implementations for inet.data types.
Byteable serialization implementations for inet.data types.
No vars found in this namespace.
Utility functions.
Utility functions.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |