inet.data.util

Utility functions.

Utility functions.
raw docstring

assert-argscljmacro

(assert-args & pairs)
source

bytes-hash-codeclj

(bytes-hash-code bytes)
(bytes-hash-code bytes initial)
(bytes-hash-code bytes offset length)
(bytes-hash-code bytes offset length initial)

Calculate a hash code for part of a byte array.

Calculate a hash code for part of a byte array.
sourceraw docstring

case-exprcljmacro

(case-expr e & clauses)

Like case, but only supports individual test expressions, which are evaluated at macro-expansion time.

Like case, but only supports individual test expressions, which are
evaluated at macro-expansion time.
sourceraw docstring

doto-letcljmacro

(doto-let bindings & body)

bindings => binding-form expr

Evaluates expr, and evaluates body with its result bound to the binding-form. Returns the result of expr.

bindings => binding-form expr

Evaluates expr, and evaluates body with its result bound to the binding-form.
Returns the result of expr.
sourceraw docstring

ffilterclj

(ffilter pred coll)

Return the first item in coll for which (pred item) is true.

Return the first item in `coll` for which `(pred item)` is true.
sourceraw docstring

ignore-errorscljmacro

(ignore-errors & body)

Return the result from body, or nil if body throws an exception.

Return the result from `body`, or `nil` if `body` throws an exception.
sourceraw docstring

longest-runclj

(longest-run x coll)

Find the longest run of the value x in the collection coll. Returns the pair of the starting index and length on success and nil on failure. When multiple runs have the same maximum length, returns the first such run.

Find the longest run of the value x in the collection coll.  Returns the
pair of the starting index and length on success and nil on failure.  When
multiple runs have the same maximum length, returns the first such run.
sourceraw docstring

sbyteclj

(sbyte x)

Return the signed byte that an unsigned integer value represents.

Return the signed byte that an unsigned integer value represents.
sourceraw docstring

ubyteclj

(ubyte x)

Return the unsigned number that a byte value represents.

Return the unsigned number that a byte value represents.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries