inet.data.util

Utility functions.

Utility functions.
raw docstring

assert-argscljmacro

(assert-args & pairs)
source

bytes-hash-codeclj

(bytes-hash-code bytes)
(bytes-hash-code bytes initial)
(bytes-hash-code bytes offset length)
(bytes-hash-code bytes offset length initial)

Calculate a hash code for a portion of a byte array.

Calculate a hash code for a portion of a byte array.
sourceraw docstring

case-exprcljmacro

(case-expr e & clauses)

Like case, but only supports individual test expressions, which are evaluated at macro-expansion time.

Like case, but only supports individual test expressions, which are
evaluated at macro-expansion time.
sourceraw docstring

doto-letcljmacro

(doto-let bindings & body)

bindings => binding-form expr

Evaluates expr, and evaluates body with its result bound to the binding-form. Returns the result of expr.

bindings => binding-form expr

Evaluates expr, and evaluates body with its result bound to the binding-form.
Returns the result of expr.
sourceraw docstring

ffilterclj

(ffilter pred coll)

Returns the first item in coll for which (pred item) is true.

Returns the first item in coll for which (pred item) is true.
sourceraw docstring

ignore-errorscljmacro

(ignore-errors & body)

Returns the result of evaluating body, or nil if it throws an exception.

Returns the result of evaluating body, or nil if it throws an exception.
sourceraw docstring

longest-runclj

(longest-run x coll)

Find the longest run of the value x in the collection coll. Returns the pair of the starting index and length on success and nil on failure.

Find the longest run of the value x in the collection coll.  Returns the
pair of the starting index and length on success and nil on failure.
sourceraw docstring

sbyteclj

(sbyte x)

Signed byte representation of an unsigned integral value.

Signed byte representation of an unsigned integral value.
sourceraw docstring

ubyteclj

(ubyte x)

Unsigned number represented by a byte value.

Unsigned number represented by a byte value.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries